import React from "react";
import type { ReactNode } from "react";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { Analytics as VercelAnalytics } from "@vercel/analytics/react";
import { AuthProvider } from "@/hooks/useAuth";
import { useReminderNotifications } from '@/hooks/useReminderNotifications';
import { useMobilePushNotifications } from '@/hooks/useMobilePushNotifications';
import { useSplashScreen } from '@/hooks/useSplashScreen';
import { MobileLayout } from '@/components/MobileLayout';
import { AnimatedSplashScreen } from '@/components/AnimatedSplashScreen';
import { SoundPermissionPrompt } from '@/components/SoundPermissionPrompt';
import { PWAInstallPrompt } from '@/components/PWAInstallPrompt';
import { OfflineIndicator } from '@/components/OfflineIndicator';
import { PerformanceMonitor } from '@/components/PerformanceMonitor';
import { preloadManager } from '@/utils/preloader';
import { lazy } from 'react';

// Lazy load routes for better initial load time
const Index = React.lazy(() => import("./pages/Index"));
const Welcome = React.lazy(() => import("./pages/Welcome"));
const NotFound = React.lazy(() => import("./pages/NotFound"));
const Profile = React.lazy(() => import("./pages/Profile"));
const About = React.lazy(() => import("./pages/About"));
const Terms = React.lazy(() => import("./pages/Terms"));
const Privacy = React.lazy(() => import("./pages/Privacy"));
const UserGuide = React.lazy(() => import("./pages/UserGuide"));
const GradeCalculator = React.lazy(() => import("./pages/GradeCalculator"));
const Pricing = React.lazy(() => import("./pages/Pricing"));
const PaymentSuccess = React.lazy(() => import("./pages/PaymentSuccess"));
const PaymentFailed = React.lazy(() => import("./pages/PaymentFailed"));
const Notifications = React.lazy(() => import("./pages/Notifications"));
const AdminTools = React.lazy(() => import("./components/AdminTools").then(module => ({ default: module.AdminTools })));
const LinksPage = React.lazy(() => import("./pages/Links"));
const CompetitionPage = React.lazy(() => import("./pages/Competition"));
const EventsPage = React.lazy(() => import("./pages/Events"));
const CompetitionQuizPage = React.lazy(() => import("./pages/CompetitionQuiz"));
const CompetitionResultsPage = React.lazy(() => import("./pages/CompetitionResults"));
const AINotes = React.lazy(() => import("./pages/AINotes"));
const Analytics = React.lazy(() => import("./pages/Analytics"));
const Referral = React.lazy(() => import("./pages/Referral"));
const Join = React.lazy(() => import("./pages/Join"));
const Community = React.lazy(() => import("./pages/Community"));
const Feedback = React.lazy(() => import("./pages/Feedback"));

// University Landing Pages
const UniversityOfAbuja = React.lazy(() => import("./pages/universities/UniversityOfAbuja"));
const NileUniversity = React.lazy(() => import("./pages/universities/NileUniversity"));
const UniversityOfLagos = React.lazy(() => import("./pages/universities/UniversityOfLagos"));
const AhmaduBelloUniversity = React.lazy(() => import("./pages/universities/AhmaduBelloUniversity"));
const UniversityOfIbadan = React.lazy(() => import("./pages/universities/UniversityOfIbadan"));
const DynamicUniversityPage = React.lazy(() => import("./pages/DynamicUniversityPage"));
const Universities = React.lazy(() => import("./pages/Universities"));

interface AppContentProps {
  children?: ReactNode;
}

// Create a component that properly uses the notification hooks
const NotificationSystem: React.FC = () => {
  // Call hooks at the top level of the component
  useReminderNotifications();
  useMobilePushNotifications();
  return null;
};

const AppContent: React.FC<AppContentProps> = ({ children }) => {
  const { showCustomSplash, hideSplash, isAppReady } = useSplashScreen();
  const [isServiceWorkerReady, setIsServiceWorkerReady] = React.useState(false);
  const [isInitialized, setIsInitialized] = React.useState(false);
  const [appState, setAppState] = React.useState('home');
  const [selectedCourseId, setSelectedCourseId] = React.useState('');
  const [quizStartTime, setQuizStartTime] = React.useState(0);

  const handleStartQuiz = () => {
    setAppState('course-selection');
  };

  const handleCourseSelect = (courseId: string) => {
    setSelectedCourseId(courseId);
    setQuizStartTime(Date.now());
    setAppState('quiz');
  };

  const handleQuizComplete = () => {
    setAppState('results');
  };

  const handleRetryQuiz = () => {
    setAppState('quiz');
  };

  const handleGoHome = () => {
    setAppState('home');
    setSelectedCourseId('');
  };

  // Initialize core features first
  React.useEffect(() => {
    if (!isInitialized && isAppReady) {
      const initializeCore = async () => {
        try {
          // Initialize service worker first
          if ('serviceWorker' in navigator) {
            await navigator.serviceWorker.ready;
            console.log('Service worker is ready');
            setIsServiceWorkerReady(true);
          }

          // Initialize preloader and other core features
          await Promise.all([
            preloadManager.initializePreloading(),
            // Add any other critical initializations here
          ]);

          setIsInitialized(true);
        } catch (error) {
          console.error('Error during initialization:', error);
          // Continue anyway to not block the app
          setIsInitialized(true);
        }
      };

      initializeCore();
    }
  }, [isAppReady, isInitialized]);

  return (
    <MobileLayout>
      <AnimatedSplashScreen 
        isVisible={showCustomSplash} 
        onComplete={hideSplash}
      />
      
      {!showCustomSplash && (
        <>
          <Sonner />
          <SoundPermissionPrompt />
          <PWAInstallPrompt />
          <OfflineIndicator />
          <PerformanceMonitor showMetrics={process.env.NODE_ENV === 'development'} />
          {isInitialized && <NotificationSystem />}
          <BrowserRouter>
            <React.Suspense fallback={
              <div className="min-h-screen flex items-center justify-center">
                <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary"></div>
              </div>
            }>
              <Routes>
                <Route path="/" element={<Index appState={appState} handleStartQuiz={handleStartQuiz} handleCourseSelect={handleCourseSelect} handleQuizComplete={handleQuizComplete} handleRetryQuiz={handleRetryQuiz} handleGoHome={handleGoHome} selectedCourseId={selectedCourseId} quizStartTime={quizStartTime} />} />
                <Route path="/welcome" element={<Welcome />} />
                <Route path="/profile" element={<Profile />} />
                <Route path="/about" element={<About />} />
                <Route path="/terms" element={<Terms />} />
                <Route path="/privacy" element={<Privacy />} />
                <Route path="/user-guide" element={<UserGuide />} />
                <Route path="/grade-calculator" element={<GradeCalculator />} />
                <Route path="/pricing" element={<Pricing />} />
                <Route path="/payment/success" element={<PaymentSuccess />} />
                <Route path="/payment/failed" element={<PaymentFailed />} />
                <Route path="/notifications" element={<Notifications />} />
                <Route path="/admin-tools" element={<AdminTools />} />
                <Route path="/ai-notes" element={<AINotes />} />
                <Route path="/analytics" element={<Analytics />} />
                <Route path="/referral" element={<Referral />} />
                <Route path="/join" element={<Join />} />
                <Route path="/community" element={<Community />} />
                <Route path="/feedback" element={<Feedback handleStartQuiz={handleStartQuiz} />} />
                <Route path="/links" element={<LinksPage />} />
                <Route path="/competition" element={<CompetitionPage />} />
                <Route path="/events" element={<EventsPage />} />
                <Route path="/competition-quiz/:competitionId/:courseId" element={<CompetitionQuizPage />} />
                <Route path="/competition-results/:competitionId" element={<CompetitionResultsPage />} />
                
                {/* Universities Directory */}
                <Route path="/universities" element={<Universities />} />
                
                {/* University Landing Pages - Specific routes for major universities */}
                <Route path="/universities/university-of-abuja" element={<UniversityOfAbuja />} />
                <Route path="/universities/nile-university-abuja" element={<NileUniversity />} />
                <Route path="/universities/university-of-lagos" element={<UniversityOfLagos />} />
                <Route path="/universities/ahmadu-bello-university-zaria" element={<AhmaduBelloUniversity />} />
                <Route path="/universities/university-of-ibadan" element={<UniversityOfIbadan />} />
                
                {/* Dynamic route for all other universities */}
                <Route path="/universities/:universitySlug" element={<DynamicUniversityPage />} />
                
                <Route path="*" element={<NotFound />} />
              </Routes>
            </React.Suspense>
          </BrowserRouter>
          <VercelAnalytics />
        </>
      )}
    </MobileLayout>
  );
};

const App: React.FC = () => {
  if (process.env.NODE_ENV === 'development') {
    console.log('App component rendering, React version:', React.version);
  }
  
  return (
    <AuthProvider>
      <TooltipProvider>
        <AppContent />
      </TooltipProvider>
    </AuthProvider>
  );
};

export default App;
